@@ -85,7 +85,7 @@ def start_server(files, serve_ip, serve_port=9000):
 
 
 def parse_xml(url):
-    node = etree.XML(re.sub(" xmlns=\"[^\"]+\"", "", requests.get(url).content.decode(), count=1).encode())
+    node = etree.XML(re.sub(" xmlns=\"[^\"]+\"", "", requests.get(url).content.decode(), count=1).encode(), parser=etree.XMLParser(recover=True))
     friendly_name = node.xpath("//friendlyName/text()")
     manufacturer_url = node.xpath("//manufacturerURL/text()")
     control_url = node.xpath("//serviceType[contains(text(), 'AVTransport')]/../controlURL/text()")
@@ -98,12 +98,12 @@ def parse_xml(url):
         "manufacturer": manufacturer and manufacturer[0],
         "manufacturer_url": manufacturer_url and manufacturer_url[0],
         "st": UPNP_DEFAULT_SERVICE_TYPE,
-        "help": "leesoar.com | Wechat MP: GMapi | secure@tom.com, chat with me.",
+        "help": "leesoar.com/real | Wechat MP: GMapi | core@111.com, chat with me.",
     }
     return data
 
 
-def get_device(timeout=5):
+def get_device(timeout=10):
     print("Scanning...")
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
     s.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_TTL, 4)
@@ -112,9 +112,9 @@ def get_device(timeout=5):
     s.sendto(SSDP_BROADCAST_MSG.encode(), (SSDP_BROADCAST_ADDR, SSDP_BROADCAST_PORT))
     s.settimeout(timeout)
 
+    scanned_devices = []
     devices = []
     while 1:
-
         try:
             data, addr = s.recvfrom(1024)
         except socket.timeout:
@@ -129,10 +129,11 @@ def get_device(timeout=5):
                 return k.lower(), v.lstrip()
 
         device = dict(map(serialize, filter(lambda x: x.count(":") >= 1, data.decode().split("\r\n"))))
-
+        if device in scanned_devices:
+            continue
         if "AVTransport" in device["st"]:
             devices.append(parse_xml(device["location"]))
-
+        scanned_devices.append(device)
     return devices
 
 
@@ -169,3 +170,5 @@ def play(files_urls, device, is_net=False):
 
     send_dlna_action(device, video_data, "SetAVTransportURI")
     send_dlna_action(device, video_data, "Play")
+
+print(get_device())
